@@ -1,19 +1,23 @@
-# Copyright (c) 2012, 2016, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
 #
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License as
-# published by the Free Software Foundation; version 2 of the
-# License.
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License, version 2.0,
+# as published by the Free Software Foundation.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
+# This program is also distributed with certain software (including
+# but not limited to OpenSSL) that is licensed under separate terms, as
+# designated in a particular file or component or in included license
+# documentation.  The authors of MySQL hereby grant you an additional
+# permission to link the program and your derivative works with the
+# separately licensed software that they have included with MySQL.
+# This program is distributed in the hope that it will be useful,  but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+# the GNU General Public License, version 2.0, for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-# 02110-1301  USA
+# along with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
 from wb import DefineModule
 
@@ -182,7 +186,7 @@ def getCatalogNames(connection):
 
     [NOTE] From MSDN: [A catalog] is equivalent to a databases in SQL Server.
     """
-    query_pre_90 = 'SELECT name FROM sys.databases'
+    query_pre_90 = 'SELECT name FROM master.dbo.sysdatabases'
     query_post_90 = 'exec sys.sp_databases'
     
     serverVersion = connected_server_version(connection)
@@ -1078,9 +1082,13 @@ def reverseEngineerTriggers(connection, schema):
     execute_query(connection, 'USE %s' % quoteIdentifier(schema.owner.name))  # catalog
     query_post_90 = """SELECT st.object_id,
     st.name AS trigger_name,
-    OBJECT_NAME(st.parent_id) AS table_name, 
-    sm.definition as trigger_code, 
-    is_disabled, is_instead_of_trigger, ''
+    OBJECT_NAME(st.parent_id) AS table_name,
+    sm.definition as trigger_code,
+    is_disabled, is_instead_of_trigger, STUFF((
+          SELECT ';' + ste.type_desc
+          FROM sys.trigger_events ste
+          WHERE st.object_id = ste.object_id
+          FOR XML PATH('')), 1, 1, '') as type_desc_detail
 FROM sys.triggers st JOIN sys.sql_modules sm ON st.object_id = sm.object_id
 WHERE st.parent_class = 1 AND OBJECT_SCHEMA_NAME(st.object_id) = '%s'
 ORDER BY st.parent_id"""
@@ -1115,9 +1123,9 @@ WHERE so.type = 'TR' AND su.name='%s'"""
             trigger.enabled = not is_disabled
             if serverVersion.majorNumber < 9:
                 trigger.event = event.strip(';')  # It would take values as 'INSERT;UPDATE'
-            else:
-                trigger.event = ';'.join(row[0] for row in execute_query(connection, 
-                                     'SELECT type_desc FROM sys.trigger_events WHERE sys.trigger_events.object_id = %d' % trigger_id))
+#            else:
+#                trigger.event = ';'.join(row[0] for row in execute_query(connection, 
+#                                     'SELECT type_desc FROM sys.trigger_events WHERE sys.trigger_events.object_id = %d' % trigger_id))
 #            trigger.orientation = 'ROW'  # TODO: This needs extra analysis
             trigger.timing = 'INSTEADOF' if is_instead_of_trigger else 'AFTER'  # NOTE: There's no equivalent for mysql BEFORE in mssql
 
